@@ -13,12 +13,14 @@ test_that("create_testset: set_names", {
   expect_error(create_testset("curve", "c1"), NA)
   expect_error(create_testset("curve", "c2"), NA)
   expect_error(create_testset("curve", "c3"), NA)
+  expect_error(create_testset("curve", "c4"), NA)
   expect_error(create_testset("curve", "C1"), NA)
   expect_error(create_testset("curve", "C2"), NA)
   expect_error(create_testset("curve", "C3"), NA)
+  expect_error(create_testset("curve", "C4"), NA)
   expect_error(create_testset("curve", c("c1", "c2")), NA)
 
-  expect_error(create_testset("curve", "c4"), "Invalid set_names")
+  expect_error(create_testset("curve", "c5"), "Invalid set_names")
   expect_error(create_testset("curve", "a1"), "Invalid set_names")
   expect_error(create_testset("curve", "abc"), "Invalid set_names")
   expect_error(create_testset("curve", c("c1", "a1")), "Invalid set_names")
